PAWpySeed: File Members

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- i
- l
- m
- n
- o
- p
- r
- s
- t
- v
- w
- y

### - a -

- add_num_cart_gridpts() : projector.h
- ae_chg_density() : density.h
- affine_transform() : utils.h
- ALLOCATION_FAILED() : utils.h

### - b -

- besselt() : projector.h

### - c -

- cartesian_to_frac() : utils.h
- CHECK_ALLOCATION() : utils.h
- CHECK_STATUS() : utils.h
- clean_wave_projections() : utils.h
- compensation_terms() : projector.h

### - d -

- determinant() : utils.h
- dist_from_frac() : utils.h
- dot() : utils.h

### - e -

- expand_symm_wf() : utils.h

### - f -

- fac() : utils.h
- fft3d() : linalg.h
- fft_calloc() : linalg.h
- fft_check() : tests.h
- frac_from_index() : utils.h
- frac_to_cartesian() : utils.h
- free_kpoint() : utils.h
- free_ppot() : utils.h
- free_ppot_list() : utils.h
- free_projection_list() : utils.h
- free_pswf() : utils.h
- free_ptr() : utils.h
- free_real_proj() : utils.h
- free_real_proj_site() : utils.h
- free_real_proj_site_list() : utils.h
- free_sbt_descriptor() : sbt.h

### - g -

- get_encut() : utils.h
- get_energy() : utils.h
- get_nband() : utils.h
- get_nspin() : utils.h
- get_nwk() : utils.h
- get_occ() : utils.h
- get_occs() : utils.h
- get_projector_list() : projector.h

### - i -

- inverse_wave_spherical_bessel_transform() : sbt.h
- is_ncl() : utils.h

### - l -

- legendre() : utils.h
- legendre_coeff() : utils.h
- legendre_product() : utils.h

### - m -

- mag() : utils.h
- make_pwave_overlap_matrices() : projector.h
- max() : utils.h
- min() : utils.h
- min_cart_path() : utils.h

### - n -

- ncl_realspace_state() : density.h

### - o -

- offsite_wave_overlap() : radial.h
- onto_projector() : projector.h
- onto_projector_helper() : projector.h
- onto_projector_ncl() : projector.h
- onto_smoothpw() : projector.h
- overlap_setup_real() : projector.h

### - p -

- proj_interpolate() : utils.h
- proj_value() : utils.h
- proj_value_helper() : utils.h
- project_realspace_state() : density.h
- projector_values() : projector.h
- pseudoprojection() : pseudoprojector.h

### - r -

- read_one_band() : reader.h
- read_wavecar() : reader.h
- read_wavefunctions() : reader.h
- read_wavefunctions_from_str() : reader.h
- realspace_state() : density.h
- realspace_state_ri() : density.h
- reciprocal_offsite_wave_overlap() : radial.h
- rotation_transform() : utils.h

### - s -

- sbf() : utils.h
- set_num_sites() : utils.h
- setup() : reader.h
- setup_projections() : projector.h
- setup_site() : utils.h
- smooth_pw_values() : projector.h
- smooth_wave_value() : utils.h
- sph_bessel() : utils.h
- spherical_bessel_transform_setup() : sbt.h
- spline_coeff() : utils.h
- spline_integral() : utils.h

### - t -

- trilinear_interpolate() : utils.h
- trilinear_interpolate_values() : utils.h

### - v -

- vc_pseudoprojection() : pseudoprojector.h
- vcross() : utils.h

### - w -

- wave_interpolate() : utils.h
- wave_spherical_bessel_transform() : sbt.h
- wave_value() : utils.h
- wave_value2() : utils.h
- wcclose() : reader.h
- wcopen() : reader.h
- wcread() : reader.h
- wcseek() : reader.h
- write_density_noreturn() : density.h
- write_density_return() : density.h
- write_realspace_state_ncl_ri() : density.h
- write_realspace_state_ri_noreturn() : density.h
- write_realspace_state_ri_return() : density.h
- write_volumetric() : density.h

### - y -

- Ylm() : utils.h
- Ylm2() : utils.h
- Ylmi() : tests.h
- Ylmr() : tests.h